@@ -205,14 +205,30 @@ typedef struct SPICE_ATTR_PACKED VDAgentMonConfig {
 
 enum {
     VD_AGENT_CONFIG_MONITORS_FLAG_USE_POS = (1 << 0),
+    VD_AGENT_CONFIG_MONITORS_FLAG_PHYSICAL_SIZE = (1 << 1),
 };
 
 typedef struct SPICE_ATTR_PACKED VDAgentMonitorsConfig {
     uint32_t num_of_monitors;
     uint32_t flags;
     VDAgentMonConfig monitors[0];
+    /* only sent if the FLAG_PHYSICAL_SIZE is present: */
+    /* VDAgentMonitorMM physical_sizes[0]; */
 } VDAgentMonitorsConfig;
 
+
+/* Physical size of the monitor in millimeters.
+ * Having this information, the remote/guest display can configure itself with
+ * appropriate font & scaling to maintain readability. */
+typedef struct SPICE_ATTR_PACKED VDAgentMonitorMM {
+    /*
+     * Note a width and height of 0 can be used to indicate a disabled
+     * monitor or no size information is present.
+     */
+    uint16_t height;
+    uint16_t width;
+} VDAgentMonitorMM;
+
 enum {
     VD_AGENT_DISPLAY_CONFIG_FLAG_DISABLE_WALLPAPER = (1 << 0),
     VD_AGENT_DISPLAY_CONFIG_FLAG_DISABLE_FONT_SMOOTH = (1 << 1),
@@ -230,6 +246,8 @@ typedef struct SPICE_ATTR_PACKED VDAgentDisplayConfig {
 #define VD_AGENT_RBUTTON_MASK (1 << 3)
 #define VD_AGENT_UBUTTON_MASK (1 << 4)
 #define VD_AGENT_DBUTTON_MASK (1 << 5)
+#define VD_AGENT_SBUTTON_MASK (1 << 6)
+#define VD_AGENT_EBUTTON_MASK (1 << 7)
 
 typedef struct SPICE_ATTR_PACKED VDAgentMouseState {
     uint32_t x;
@@ -264,6 +282,12 @@ enum {
     VD_AGENT_CLIPBOARD_IMAGE_BMP,  /* optional */
     VD_AGENT_CLIPBOARD_IMAGE_TIFF, /* optional */
     VD_AGENT_CLIPBOARD_IMAGE_JPG,  /* optional */
+    /* identifies a list of absolute paths in phodav server
+     * that is associated with the "org.spice-space.webdav.0" webdav channel;
+     * the items are encoded in UTF-8 and separated by '\0';
+     * the first item must be either "copy" or "cut" (without the quotes)
+     * to indicate what action should be performed with the files that follow */
+    VD_AGENT_CLIPBOARD_FILE_LIST,
 };
 
 enum {
